@@ -20,9 +20,7 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
 #include "mtools.h"
-#include "vfat.h"
 #include "fs.h"
 #include "mainloop.h"
 #include "plain_io.h"
